@@ -2,16 +2,12 @@ package Catmandu::Fix::add_field;
 
 use Catmandu::Sane;
 use Moo;
+use Catmandu::Fix::Has;
 
 with 'Catmandu::Fix::Base';
 
-has path  => (is => 'ro', required => 1);
-has value => (is => 'ro', required => 1);
-
-around BUILDARGS => sub {
-    my ($orig, $class, $path, $value) = @_;
-    $orig->($class, path => $path, value => $value);
-};
+has path  => (fix_arg => 1);
+has value => (fix_arg => 1);
 
 sub emit {
     my ($self, $fixer) = @_;
@@ -35,14 +31,14 @@ if they are missing.
 
 =head1 SYNOPSIS
 
-   # Add a new field 'foo' with value '2'
-   add_field('foo','2');
+   # Add a new field 'foo' with value 2
+   add_field(foo, 2)
 
    # Change the value of 'foo' to 'bar 123'
-   add_field('foo','bar 123');
+   add_field(foo, 'bar 123')
 
    # Create a deeply nested key
-   add_field('my.deep.nested.key','hi');
+   add_field(my.deep.nested.key, hi)
 
 =head1 SEE ALSO
 
